﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Input;
using System.Windows.Controls;
using System.Windows.Threading;
using System.Globalization;
using System.Threading;
using System.IO;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WpfDesktopEdition;

namespace Lines
{
	/// <summary>
	/// Interaction logic for MainWindow.xaml
	/// </summary>
	public partial class MainWindow : Window
	{

		/*---------------------------------------------------------------------------------*/
		public MainWindow()
		{
			InitializeComponent();
		}

		/*---------------------------------------------------------------------------------*/
		private void wpfMap_Loaded(object sender, RoutedEventArgs e)
		{
			wpfMap.BackgroundOverlay.BackgroundBrush = new GeoSolidBrush(GeoColor.GeographicColors.ShallowOcean);
			wpfMap.MapUnit = GeographyUnit.Meter;

			InMemoryFeatureLayer points = new InMemoryFeatureLayer();
			points.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.CreateSimplePointStyle(PointSymbolType.Circle, GeoColor.StandardColors.Red, 5);
			points.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
			points.IsVisible = true;
			points.Open();

			InMemoryFeatureLayer lines = new InMemoryFeatureLayer();
			lines.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(new CustomStartEndLineStyle(wpfMap));
			lines.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
			lines.IsVisible = true;
			lines.Open();

			LayerOverlay dynamicOverlay = new LayerOverlay();
			dynamicOverlay.TileType = TileType.SingleTile;
			dynamicOverlay.Layers.Add("points", points);
			dynamicOverlay.Layers.Add("lines", lines);
			wpfMap.Overlays.Add("DynamicOverlay", dynamicOverlay);

			var v1 = new Vertex(-165264.8047, 7112501.7313);
			var v2 = new Vertex(-145661.5537, 7111930.0113);

			var p1 = new PointShape(v1);
			var p2 = new PointShape(v2);

			points.InternalFeatures.Add(p1.GetFeature());
			points.InternalFeatures.Add(p2.GetFeature());

			MultilineShape line = p1.GetShortestLineTo(p2, GeographyUnit.Meter);
			Feature lineFeature = new Feature(line);
			lines.InternalFeatures.Add(lineFeature.Id, lineFeature);

			Collection<BaseShape> rectangleShapes = new Collection<BaseShape>();
			if (points.HasBoundingBox)
				rectangleShapes.Add(points.GetBoundingBox());
			if (lines.HasBoundingBox)
				rectangleShapes.Add(lines.GetBoundingBox());

			wpfMap.CurrentExtent = ExtentHelper.GetBoundingBoxOfItems(rectangleShapes);
		}
	}
}
